@@ -12,18 +12,14 @@ no warnings 'uninitialized';
 @EXPORT_OK  = qw( mhilb mvander mpart mhankel mtoeplitz mtri mpascal mcompanion);
 %EXPORT_TAGS = (Func=>[@EXPORT_OK]);
 
-our $VERSION = '0.08_02';
-$VERSION = eval $VERSION;
-
+our $VERSION = 0.01;
 our @ISA = ( 'PDL::Exporter');
 
 use strict;
 
-=encoding Latin-1
-
 =head1 NAME
 
-PDL::LinearAlgebra::Special - Special matrices for PDL
+PDL::LinearAlgebra::Special - Special matrix for PDL
 
 =head1 SYNOPSIS
 
@@ -33,7 +29,7 @@ PDL::LinearAlgebra::Special - Special matrices for PDL
 
 =head1 DESCRIPTION
 
-This module provides some constructors of well known matrices.
+This module provides some known matrix.
 
 =head1 FUNCTIONS
 
@@ -80,7 +76,7 @@ Uses L<tricpy|PDL::LinearAlgebra::Real/tricpy> or L<tricpy|PDL::LinearAlgebra::C
 
 =for usage
 
- PDL = mtri(PDL, SCALAR)
+ PDL = mtri(SCALAR)
  SCALAR : UPPER = 0 | LOWER = 1, default = 0
 
 =for example
@@ -304,7 +300,7 @@ sub PDL::mpascal {
 		require PDL::Stat::Distributions;
 		$mat = xvals($m);
 		if ($n > 1){
-			return (PDL::Stat::Distributions::choose($mat + $mat->dummy(0),$mat))[0];		
+			return PDL::Stat::Distributions::choose($mat + $mat->dummy(0),$mat);		
 		}
 		else{
 			$mat = PDL::Stat::Distributions::choose($mat,$mat->dummy(0));
@@ -316,7 +312,7 @@ sub PDL::mpascal {
 			require PDL::GSLSF::GAMMA;
 			if ($n > 1){
 				$mat = xvals($m);
-				return (PDL::GSLSF::GAMMA::gsl_sf_choose($mat + $mat->dummy(0),$mat))[0];					
+				return PDL::GSLSF::GAMMA::gsl_sf_choose($mat + $mat->dummy(0),$mat);					
 			}else{
 				$mat = xvals($m, $m);
 				return (PDL::GSLSF::GAMMA::gsl_sf_choose($mat->tritosym,$mat->xchg(0,1)->tritosym))[0]->mtri($n);
@@ -375,9 +371,13 @@ sub PDL::mcompanion{
 }
 
 
+=head1 TODO
+
+	TODO
+
 =head1 AUTHOR
 
-Copyright (C) Grgory Vanuxem 2005-2007.
+Copyright (C) Grgory Vanuxem 2005.
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the artistic license as specified in the Artistic
